Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Master ¶
type Master struct {
Variants []*Variant
// contains filtered or unexported fields
}
Master is a struct for interacting with the master playlist.
func (*Master) GetVariant ¶
GetVariant returns a Variant struct representing the variant's data.
func (*Master) GetVariantList ¶
GetVariantList gets a printable list of variants
type Session ¶
Session Stores state information
func (*Session) GetMasterPlaylistOptions ¶
GetMasterPlaylistOptions return the possible playlist options.
func (*Session) GetVariantPrintData ¶
GetVariantPrintData return the last n segments of a variant.
func (*Session) SetVariant ¶
SetVariant sets the variant used for requesting data
type Variant ¶
type Variant struct {
Tags []string
URL string
Resolution string
Bandwidth int
Codecs string
Segments [][]string
// contains filtered or unexported fields
}
Variant is a struct for storing data about a variant.
func (*Variant) GetHeaderTagsToPrint ¶ added in v1.0.11
GetHeaderTagsToPrint returns a the header tags for printing.
func (*Variant) GetSegmentsToPrint ¶
GetSegmentsToPrint compiles the text list of segments to print.
Click to show internal directories.
Click to hide internal directories.